==> cxf-bundle-2.1.1-sources.jar: org/apache/cxf/binding/coloc/feature/ColocFeature.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.binding.coloc.feature;

import org.apache.cxf.Bus;
import org.apache.cxf.binding.coloc.ColocInInterceptor;
import org.apache.cxf.binding.coloc.ColocOutInterceptor;
import org.apache.cxf.endpoint.Client;
import org.apache.cxf.endpoint.ConduitSelector;
import org.apache.cxf.endpoint.DeferredConduitSelector;
import org.apache.cxf.feature.AbstractFeature;
import org.apache.cxf.interceptor.InterceptorProvider;

public class ColocFeature extends AbstractFeature {
    private static final ColocOutInterceptor COLOC_OUT = new ColocOutInterceptor();
    private static final ColocInInterceptor COLOC_IN = new ColocInInterceptor();

    @Override
    public void initialize(Client client, Bus bus) {
        ConduitSelector selector = new DeferredConduitSelector();
        selector.setEndpoint(client.getEndpoint());
        client.setConduitSelector(selector);
        initializeProvider(client, bus);
    }
    
    @Override
    protected void initializeProvider(InterceptorProvider provider, Bus bus) {
        COLOC_OUT.setBus(bus);
        provider.getInInterceptors().add(COLOC_IN);
        provider.getOutInterceptors().add(COLOC_OUT);
    }
}

==> cxf-bundle-2.7.11-sources.jar: org/apache/cxf/binding/coloc/feature/ColocFeature.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.binding.coloc.feature;

import org.apache.cxf.Bus;
import org.apache.cxf.binding.coloc.ColocInInterceptor;
import org.apache.cxf.binding.coloc.ColocOutInterceptor;
import org.apache.cxf.common.injection.NoJSR250Annotations;
import org.apache.cxf.endpoint.Client;
import org.apache.cxf.endpoint.ConduitSelector;
import org.apache.cxf.endpoint.DeferredConduitSelector;
import org.apache.cxf.feature.AbstractFeature;
import org.apache.cxf.interceptor.InterceptorProvider;

@NoJSR250Annotations
public class ColocFeature extends AbstractFeature {

    @Override
    public void initialize(Client client, Bus bus) {
        ConduitSelector selector = new DeferredConduitSelector();
        selector.setEndpoint(client.getEndpoint());
        client.setConduitSelector(selector);
        initializeProvider(client, bus);
    }
    
    @Override
    protected void initializeProvider(InterceptorProvider provider, Bus bus) {
        provider.getInInterceptors().add(new ColocInInterceptor());
        provider.getOutInterceptors().add(new ColocOutInterceptor(bus));
    }
}
